@@ -53,8 +53,10 @@ class BotInfo(BaseModel):
     bot_token: str
     chat_ids: List[int]
     info_level: TaskState = TaskState.no_info
-    info_on_execution_start: bool = False
-    info_on_execution_end: bool = True
+    info_on_start: bool = False
+    info_on_success: bool = True
+    info_on_exception: bool = True
+    msg_on_start: str = None
     msg_on_success: str = None
     msg_on_exception: str = None
 
@@ -176,19 +178,22 @@ class Task(BaseModel):
     def execution_info_start(self, warning: str = None):
         # send bot info
         for bot_info in self.job_info.bot_info:
-            if bot_info.info_on_execution_start:
-                if warning is not None:
-                    msg = f"⚠️ Warning\n<code>{warning}</code>\n\n"
+            if bot_info.info_on_start:
+                if bot_info.msg_on_start is None:
+                    if warning is not None:
+                        msg = f"⚠️ Warning\n<code>{warning}</code>\n\n"
+                    else:
+                        msg = f"📍 execution started\n"
+                    msg += f"<code>{self.__repr__()}</code>"
                 else:
-                    msg = f"📍 execution started\n"
-                msg += f"<code>{self.__repr__()}</code>"
+                    msg = bot_info.msg_on_start
                 self.send_bot_info(bot_info, msg)
 
     def execution_info_end(self, result: str = None, duration: timedelta = None):
         query = f"INSERT INTO db_global.Executions(task_id, result_msg, duration) VALUES (%s,%s,%s)"
         _ = execute_query(query, (self.id, result, str(duration)))
         for bot_info in self.job_info.bot_info:
-            if bot_info.info_on_execution_end:
+            if bot_info.info_on_success:
                 if bot_info.msg_on_success is None:
                     msg = f"✅ execution finished\n"
                     msg += f"<code>{self.__repr__()}</code>"
@@ -203,7 +208,7 @@ class Task(BaseModel):
         error_msg = f"{type(error).__name__}: {error}"
         _ = execute_query(query, (self.id, error_msg, str(duration)))
         for bot_info in self.job_info.bot_info:
-            if bot_info.info_on_execution_end:
+            if bot_info.info_on_exception:
                 if bot_info.msg_on_exception is None:
                     msg = f"❌ execution finished with error\n"
                     msg += f"<code>{self.__repr__()}</code>"
